/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
import { ElementRef, Injector, NgZone, ViewContainerRef, ChangeDetectorRef, Type } from '@angular/core';
import { Directionality } from '@angular/cdk/bidi';
import { Overlay } from '@angular/cdk/overlay';
import { CdkColumnDef, _CoalescedStyleScheduler } from '@angular/cdk/table';
import { ColumnResize } from '../column-resize';
import { ColumnResizeNotifierSource } from '../column-resize-notifier';
import { ResizeStrategy } from '../resize-strategy';
import { HeaderRowEventDispatcher } from '../event-dispatcher';
import { Resizable } from '../resizable';
import { MatColumnResizeOverlayHandle } from '../overlay-handle';
import * as i0 from "@angular/core";
/**
 * Explicitly enables column resizing for a mat-header-cell.
 */
export declare class MatResizable extends Resizable<MatColumnResizeOverlayHandle> {
    protected readonly columnDef: CdkColumnDef;
    protected readonly columnResize: ColumnResize;
    protected readonly directionality: Directionality;
    protected readonly elementRef: ElementRef;
    protected readonly eventDispatcher: HeaderRowEventDispatcher;
    protected readonly injector: Injector;
    protected readonly ngZone: NgZone;
    protected readonly overlay: Overlay;
    protected readonly resizeNotifier: ColumnResizeNotifierSource;
    protected readonly resizeStrategy: ResizeStrategy;
    protected readonly styleScheduler: _CoalescedStyleScheduler;
    protected readonly viewContainerRef: ViewContainerRef;
    protected readonly changeDetectorRef: ChangeDetectorRef;
    protected readonly document: Document;
    minWidthPxInternal: number;
    constructor(columnDef: CdkColumnDef, columnResize: ColumnResize, directionality: Directionality, document: any, elementRef: ElementRef, eventDispatcher: HeaderRowEventDispatcher, injector: Injector, ngZone: NgZone, overlay: Overlay, resizeNotifier: ColumnResizeNotifierSource, resizeStrategy: ResizeStrategy, styleScheduler: _CoalescedStyleScheduler, viewContainerRef: ViewContainerRef, changeDetectorRef: ChangeDetectorRef);
    protected getInlineHandleCssClassName(): string;
    protected getOverlayHandleComponentType(): Type<MatColumnResizeOverlayHandle>;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatResizable, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MatResizable, "mat-header-cell[resizable], th[mat-header-cell][resizable]", never, { "settings": { "alias": "resizable"; "required": false; }; }, {}, never, never, true, never>;
}
